@@ -29,6 +29,14 @@ class LinkFacter(Facter):
             'total.number.links': {
                 'title': 'Link count',
                 'description': lambda value: "This page has %d outbound links." % value
+            },
+            'total.number.invalid_links': {
+                'title': 'Total invalid links',
+                'description': lambda value: "This page has %d invalid links." % value
+            },
+            'page.invalid_links': {
+                'title': 'Invalid Links',
+                'description': lambda value: list(value),
             }
         }
 
@@ -51,6 +59,8 @@ class LinkFacter(Facter):
             value=set(),
         )
 
+        invalid_links = set()
+
         num_links = 0
 
         links_to_get = set()
@@ -62,6 +72,10 @@ class LinkFacter(Facter):
             if not url:
                 continue
 
+            if not self.is_valid(url):
+                invalid_links.add(url)
+                continue
+
             if self.looks_like_image(url):
                 continue
 
@@ -88,6 +102,16 @@ class LinkFacter(Facter):
             value=num_links
         )
 
+        self.add_fact(
+            key='total.number.invalid_links',
+            value=len(invalid_links)
+        )
+
+        self.add_fact(
+            key='page.invalid_links',
+            value=invalid_links
+        )
+
     def handle_url_loaded(self, url, response):
         logging.debug('Got response (%s) from %s!' % (response.status_code, url))
         self.review.facts['page.links']['value'].add(url)
